//-----------------------------------------------------------------------
// <copyright file="DancTeXCommandLineBuilder.cs" company="Cord Burmeister">
//     Copyright  2012 Cord Burmeister. All rights reserved.
// 	Microsoft Public License (http://www.microsoft.com/opensource/licenses.mspx#Ms-PL)
// </copyright>
// <authorCord Burmeister</author>
// <email>danctex2010@outlook.com</email>
//-----------------------------------------------------------------------
namespace DancTeX.Build.Tasks
{
    using System;
    using System.Globalization;
    using System.IO;
    using Microsoft.Build.Framework;
    using Microsoft.Build.Utilities;

    /// <summary>
    /// Helper class for appending the command line arguments.
    /// </summary>
    public class DancTeXCommandLineBuilder : CommandLineBuilder
    {
        /// <summary>
        /// Internal const for unspecified constants
        /// </summary>
        internal const int Unspecified = -1;

        /// <summary>
        /// Append a switch to the command line if the value has been specified.
        /// </summary>
        /// <param name="switchName">Switch to append.</param>
        /// <param name="value">Value specified by the user.</param>
        public void AppendIfSpecified(string switchName, int value)
        {
            if (value != Unspecified)
            {
                AppendSwitchIfNotNull(switchName, value.ToString(CultureInfo.InvariantCulture));
            }
        }

        /// <summary>
        /// Append a switch to the command line if the condition is true.
        /// </summary>
        /// <param name="switchName">Switch to append.</param>
        /// <param name="condition">Condition specified by the user.</param>
        public void AppendIfTrue(string switchName, bool condition)
        {
            if (condition)
            {
                AppendSwitch(switchName);
            }
        }

        /// <summary>
        /// Append a switch to the command line if any values in the array have been specified.
        /// </summary>
        /// <param name="switchName">Switch to append.</param>
        /// <param name="values">Values specified by the user.</param>
        public void AppendArrayIfNotNull(string switchName, ITaskItem[] values)
        {
            if (values != null)
            {
                foreach (ITaskItem value in values)
                {
                    AppendSwitchIfNotNull(switchName, value);
                }
            }
        }

        /// <summary>
        /// Append a switch to the command line if any values in the array have been specified.
        /// </summary>
        /// <param name="switchName">Switch to append.</param>
        /// <param name="values">Values specified by the user.</param>
        public void AppendArrayIfNotNull(string switchName, string[] values)
        {
            if (values != null)
            {
                foreach (string value in values)
                {
                    AppendSwitchIfNotNull(switchName, value);
                }
            }
        }

        /// <summary>
        /// Append arbitrary text to the command-line if specified.
        /// </summary>
        /// <param name="textToAppend">Text to append.</param>
        public void AppendTextIfNotNull(string textToAppend)
        {
            if (!String.IsNullOrEmpty(textToAppend))
            {
                AppendSpaceIfNotEmpty();
                AppendTextUnquoted(textToAppend);
            }
        }
    }
}