//-----------------------------------------------------------------------
// <copyright file="DancTeXToolTask.cs" company="Cord Burmeister">
//     Copyright  2012 Cord Burmeister. All rights reserved.
// 	Microsoft Public License (http://www.microsoft.com/opensource/licenses.mspx#Ms-PL)
// </copyright>
// <authorCord Burmeister</author>
// <email>danctex2010@outlook.com</email>
//-----------------------------------------------------------------------
namespace DancTeX.Build.Tasks
{
    using System;
    using Microsoft.Build.Utilities;

    /// <summary>
    /// Base class for WiX tool tasks; executes tools in-process
    /// so that repeated invocations are much faster.
    /// </summary>
    public abstract class DancTeXToolTask : ToolTask, IDisposable
    {
        /// <summary>
        /// Remember if this instance is disposed
        /// </summary>
        private bool disposed;

        /// <summary>
        /// Cleans up the ManualResetEvent members
        /// </summary>
        public void Dispose()
        {
            if (!this.disposed)
            {
                this.Dispose(true);
                GC.SuppressFinalize(this);
                this.disposed = true;
            }
        }

        /// <summary>
        /// Cleans up the ManualResetEvent members
        /// </summary>
        /// <param name="disposing">if set to <c>true</c> [disposing].</param>
        protected virtual void Dispose(bool disposing)
        {
            if (disposing)
            {
            }
        }
    }
}