//-----------------------------------------------------------------------
// <copyright file="ReadMiKTeXConfiguration.cs" company="Cord Burmeister">
//     Copyright  2012 Cord Burmeister. All rights reserved.
// 	Microsoft Public License (http://www.microsoft.com/opensource/licenses.mspx#Ms-PL)
// </copyright>
// <authorCord Burmeister</author>
// <email>danctex2010@outlook.com</email>
//-----------------------------------------------------------------------
using System;
using Microsoft.Build.Framework;
using Microsoft.Build.Utilities;

namespace DancTeX
{
    /// <summary>
    /// An MSBuild task to run the LaTeX compiler.
    /// </summary>
    [Serializable]
    [LoadInSeparateAppDomain]
    public sealed class ReadMikTeXConfiguration : AppDomainIsolatedTask, IDisposable
    {

        /// <summary>
        /// Remember if anything is disposed
        /// </summary>
        private bool _disposed;

        /// <summary>
        /// The path to the tools
        /// </summary>
        private ITaskItem _toolPath;

        /// <summary>
        /// Gets or sets IntermediateFiles
        /// </summary>        /// <value>The output file.</value>
        [Output]
        public ITaskItem ConfigurationPath
        {
            get
            {
                return _toolPath;
            }
            set
            {
                _toolPath = value;
            }
        }

    

        /// <summary>
        /// Cleans up the Texify members
        /// </summary>
        /// <exception cref="System.ArgumentNullException">Thrown when SuppressFinalize throws exception. </exception>
        public void Dispose()
        {
            if (_disposed)
            {
                return;
            }

            //this.Dispose(true);
            GC.SuppressFinalize(this);
            _disposed = true;
        }

        /// <summary>
        /// Read out the configuration path from the COM object
        /// </summary>
        /// <returns>
        /// true if successful; otherwise, false.
        /// </returns>
        public override bool Execute()
        {
            MiKTeXSession2_9.ISession2 session = new MiKTeXSession2_9.MiKTeXSession2_9Class();
            MiKTeXSession2_9.MiKTeXSetupInfo setupInfo = session.GetMiKTeXSetupInfo();

            _toolPath =  new TaskItem (setupInfo.binDirectory);
            return true;
        }

        #region IDisposable Members

        /// <summary>
        /// Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
        /// </summary>
        void IDisposable.Dispose()
        {
        }

        #endregion
    }
}